@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_autoscaling_common._jsii
 import aws_cdk.aws_cloudwatch._jsii
@@ -16,9 +16,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-applicationautoscaling",
-    "1.63.0",
+    "1.65.0",
     __name__[0:-6],
-    "aws-applicationautoscaling@1.63.0.jsii.tgz",
+    "aws-applicationautoscaling@1.65.0.jsii.tgz",
 )
 
 __all__ = [
